# 6 "src/languages/smtlib2/v2.6/script/lexer.mll"
 
  exception Error

  module T = Dolmen_std.Tok
  module M = Map.Make(String)

  open Tokens

  (* Token printing *)

  let keyword_descr s =
    T.descr s ~kind:"keyword"

  let reserved_descr s =
    T.descr s ~kind:"reserved word"

  let descr token : T.descr =
    match (token : token) with
    | EOF -> T.descr ~kind:"end of file token" ""
    | OPEN -> T.descr ~article:"an" ~kind:"opening parenthesis" ""
    | CLOSE -> T.descr ~article:"a" ~kind:"closing parenthesis" ""
    | NUM s -> T.descr ~kind:"integer" s
    | DEC s -> T.descr ~kind:"decimal" s
    | HEX s -> T.descr ~kind:"hexadecimal" s
    | BIN s -> T.descr ~kind:"binary" s
    | STR s -> T.descr ~kind:"string" s
    | SYMBOL s -> T.descr ~kind:"symbol" s
    | KEYWORD s -> keyword_descr s
    | UNDERSCORE -> reserved_descr "_"
    | ATTRIBUTE -> reserved_descr "!"
    | AS -> reserved_descr "as"
    | LET -> reserved_descr "let"
    | EXISTS -> reserved_descr "exists"
    | FORALL -> reserved_descr "forall"
    | MATCH -> reserved_descr "match"
    | PAR -> reserved_descr "par"
    | ASSERT -> reserved_descr "assert"
    | CHECK_SAT -> reserved_descr "check-sat"
    | CHECK_SAT_ASSUMING -> reserved_descr "check-sat-assuming"
    | DECLARE_CONST -> reserved_descr "declare-const"
    | DECLARE_DATATYPE -> reserved_descr "declare-datatype"
    | DECLARE_DATATYPES -> reserved_descr "declare-datatypes"
    | DECLARE_FUN -> reserved_descr "declare-fun"
    | DECLARE_SORT -> reserved_descr "declare-sort"
    | DEFINE_FUN -> reserved_descr "define-fun"
    | DEFINE_FUN_REC -> reserved_descr "define-fun-rec"
    | DEFINE_FUNS_REC -> reserved_descr "define-funs-rec"
    | DEFINE_SORT -> reserved_descr "define-sort"
    | ECHO -> reserved_descr "echo"
    | EXIT -> reserved_descr "exit"
    | GET_ASSERTIONS -> reserved_descr "get-assertions"
    | GET_ASSIGNMENT -> reserved_descr "gert-assignment"
    | GET_INFO -> reserved_descr "get-info"
    | GET_MODEL -> reserved_descr "get-model"
    | GET_OPTION -> reserved_descr "get-option"
    | GET_PROOF -> reserved_descr "get-proof"
    | GET_UNSAT_ASSUMPTIONS -> reserved_descr "get-unsat-assumptions"
    | GET_UNSAT_CORE -> reserved_descr "get-unsat-core"
    | GET_VALUE -> reserved_descr "get-value"
    | POP -> reserved_descr "pop"
    | PUSH -> reserved_descr "push"
    | RESET -> reserved_descr "reset"
    | RESET_ASSERTIONS -> reserved_descr "reset-assertions"
    | SET_INFO -> reserved_descr "set-info"
    | SET_LOGIC -> reserved_descr "set-logic"
    | SET_OPTION -> reserved_descr "set-option"

  (* Token parsing *)

  let bind map (x, v) = M.add x v map

  let reserved_words =
    List.fold_left bind M.empty [
    (* reserved words *)
      (* These are currently unused in smtlib scripts commands
       * (they are only used in logic definitions), hence they are currently
       * ignored, given that only scripts are currently parsed.
    "BINARY", BINARY;
    "DECIMAL", DECIMAL;
    "HEXADECIMAL", HEXADECIMAL;
    "NUMERAL", NUMERAL;
    "STRING", STRING;
      *)
    "_", UNDERSCORE;
    "!", ATTRIBUTE;
    "as", AS;
    "let", LET;
    "exists", EXISTS;
    "forall", FORALL;
    "match", MATCH;
    "par", PAR;
    (* command names *)
    "assert", ASSERT;
    "check-sat", CHECK_SAT;
    "check-sat-assuming", CHECK_SAT_ASSUMING;
    "declare-const", DECLARE_CONST;
    "declare-datatype", DECLARE_DATATYPE;
    "declare-datatypes", DECLARE_DATATYPES;
    "declare-fun", DECLARE_FUN;
    "declare-sort", DECLARE_SORT;
    "define-fun", DEFINE_FUN;
    "define-fun-rec", DEFINE_FUN_REC;
    "define-funs-rec", DEFINE_FUNS_REC;
    "define-sort", DEFINE_SORT;
    "echo", ECHO;
    "exit", EXIT;
    "get-assertions", GET_ASSERTIONS;
    "get-assignment", GET_ASSIGNMENT;
    "get-info", GET_INFO;
    "get-model", GET_MODEL;
    "get-option", GET_OPTION;
    "get-proof", GET_PROOF;
    "get-unsat-assumptions", GET_UNSAT_ASSUMPTIONS;
    "get-unsat-core", GET_UNSAT_CORE;
    "get-value", GET_VALUE;
    "pop", POP;
    "push", PUSH;
    "reset", RESET;
    "reset-assertions", RESET_ASSERTIONS;
    "set-info", SET_INFO;
    "set-logic", SET_LOGIC;
    "set-option", SET_OPTION;
  ]

  let symbol newline lexbuf s =
    (* register the newlines in quoted symbols to maintain correct locations.*)
    for i = 0 to (String.length s - 1) do
      match s.[i] with
      | '\n' -> newline lexbuf
      | _ -> ()
    done;
    (* Check whether the symbol is a reserved word. *)
    try M.find s reserved_words
    with Not_found -> SYMBOL s


# 139 "src/languages/smtlib2/v2.6/script/lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\127\000\126\000\222\000\245\255\151\000\224\000\045\000\
    \250\255\251\255\093\001\253\255\007\000\255\255\080\001\090\001\
    \100\001\044\000\110\001\133\001\088\000\203\001\243\255\080\002\
    \253\255\010\000\255\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\012\000\255\255\255\255\255\255\006\000\006\000\
    \255\255\255\255\003\000\255\255\001\000\255\255\255\255\007\000\
    \007\000\255\255\255\255\008\000\009\000\011\000\255\255\255\255\
    \255\255\001\000\255\255";
  Lexing.lex_default =
   "\255\255\001\000\255\255\255\255\000\000\255\255\255\255\255\255\
    \000\000\000\000\010\000\000\000\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\024\000\
    \000\000\255\255\000\000";
  Lexing.lex_trans =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\012\000\011\000\000\000\000\000\012\000\000\000\000\000\
    \012\000\000\000\000\000\000\000\012\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \012\000\002\000\004\000\005\000\002\000\002\000\002\000\012\000\
    \009\000\008\000\002\000\002\000\026\000\002\000\002\000\002\000\
    \007\000\006\000\006\000\006\000\006\000\006\000\006\000\006\000\
    \006\000\006\000\003\000\010\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\014\000\020\000\020\000\002\000\002\000\
    \000\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\000\000\001\000\000\000\002\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \020\000\020\000\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\002\000\
    \000\000\000\000\002\000\002\000\002\000\000\000\000\000\000\000\
    \002\000\002\000\000\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \000\000\000\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\000\000\000\000\255\255\002\000\002\000\000\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\017\000\000\000\022\000\002\000\000\000\255\255\021\000\
    \013\000\000\000\021\000\021\000\021\000\000\000\000\000\000\000\
    \021\000\021\000\000\000\021\000\021\000\021\000\014\000\018\000\
    \006\000\006\000\006\000\006\000\006\000\006\000\006\000\006\000\
    \006\000\006\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\000\000\000\000\000\000\021\000\021\000\000\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\000\000\000\000\000\000\021\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\000\000\255\255\
    \016\000\015\000\015\000\015\000\015\000\015\000\015\000\015\000\
    \015\000\015\000\015\000\015\000\015\000\015\000\015\000\015\000\
    \015\000\015\000\015\000\015\000\016\000\015\000\015\000\015\000\
    \015\000\015\000\015\000\015\000\015\000\015\000\019\000\019\000\
    \019\000\019\000\019\000\019\000\019\000\019\000\019\000\019\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\019\000\
    \019\000\019\000\019\000\019\000\019\000\019\000\019\000\019\000\
    \019\000\019\000\019\000\019\000\019\000\019\000\019\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\019\000\019\000\
    \019\000\019\000\019\000\019\000\000\000\000\000\000\000\019\000\
    \019\000\019\000\019\000\019\000\019\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\019\000\019\000\
    \019\000\019\000\019\000\019\000\021\000\000\000\000\000\021\000\
    \021\000\021\000\000\000\000\000\000\000\021\000\021\000\000\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\000\000\000\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\000\000\000\000\
    \000\000\021\000\021\000\000\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\000\000\000\000\
    \000\000\021\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\025\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255";
  Lexing.lex_check =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\255\255\000\000\255\255\255\255\
    \012\000\255\255\255\255\255\255\012\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\012\000\
    \000\000\000\000\000\000\000\000\025\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\007\000\017\000\017\000\000\000\000\000\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\000\000\255\255\000\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \020\000\020\000\001\000\001\000\255\255\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\002\000\
    \255\255\255\255\002\000\002\000\002\000\255\255\255\255\255\255\
    \002\000\002\000\255\255\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \255\255\255\255\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\255\255\255\255\001\000\002\000\002\000\255\255\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\005\000\255\255\001\000\002\000\255\255\001\000\003\000\
    \000\000\255\255\003\000\003\000\003\000\255\255\255\255\255\255\
    \003\000\003\000\255\255\003\000\003\000\003\000\006\000\005\000\
    \006\000\006\000\006\000\006\000\006\000\006\000\006\000\006\000\
    \006\000\006\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\255\255\255\255\255\255\003\000\003\000\255\255\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\255\255\255\255\255\255\003\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\255\255\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\255\255\255\255\001\000\
    \014\000\014\000\014\000\014\000\014\000\014\000\014\000\014\000\
    \014\000\014\000\015\000\015\000\015\000\015\000\015\000\015\000\
    \015\000\015\000\015\000\015\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\018\000\
    \018\000\018\000\018\000\018\000\018\000\019\000\019\000\019\000\
    \019\000\019\000\019\000\019\000\019\000\019\000\019\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\019\000\019\000\
    \019\000\019\000\019\000\019\000\255\255\255\255\255\255\018\000\
    \018\000\018\000\018\000\018\000\018\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\010\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\019\000\019\000\
    \019\000\019\000\019\000\019\000\021\000\255\255\255\255\021\000\
    \021\000\021\000\255\255\255\255\255\255\021\000\021\000\255\255\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\255\255\255\255\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\255\255\255\255\
    \255\255\021\000\021\000\255\255\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\021\000\021\000\
    \021\000\021\000\021\000\021\000\021\000\021\000\255\255\255\255\
    \255\255\021\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
    \023\000\255\255\255\255\023\000\023\000\010\000\023\000\023\000\
    \023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
    \023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
    \255\255\255\255\023\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\023\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \023\000";
  Lexing.lex_base_code =
   "\000\000\001\000\094\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\009\000\000\000\
    \000\000\000\000\000\000";
  Lexing.lex_backtrk_code =
   "\000\000\000\000\009\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000";
  Lexing.lex_default_code =
   "\000\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000";
  Lexing.lex_trans_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\000\000\000\000\001\000\001\000\001\000\000\000\
    \000\000\000\000\001\000\001\000\000\000\001\000\001\000\001\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\000\000\000\000\000\000\001\000\001\000\
    \000\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\000\000\004\000\000\000\001\000\001\000\
    \000\000\000\000\001\000\001\000\001\000\000\000\000\000\000\000\
    \001\000\001\000\000\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \000\000\000\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\000\000\000\000\000\000\001\000\001\000\000\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\000\000\000\000\000\000\001\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check_code =
   "\255\255\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\255\255\255\255\001\000\001\000\255\255\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\000\000\255\255\255\255\000\000\000\000\000\000\255\255\
    \255\255\255\255\000\000\000\000\255\255\000\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\001\000\000\000\000\000\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\000\000\001\000\000\000\002\000\
    \001\000\255\255\002\000\002\000\002\000\255\255\255\255\255\255\
    \002\000\002\000\255\255\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \255\255\255\255\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\255\255\255\255\255\255\002\000\002\000\255\255\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
    \002\000\255\255\255\255\255\255\002\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\001\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_code =
   "\255\003\255\255\003\255\002\255\255\001\002\000\003\255";
}

let rec token newline lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 4 (-1);(* L=1 [2] <- p ;  *)
  lexbuf.Lexing.lex_mem.(2) <- lexbuf.Lexing.lex_curr_pos ;
 __ocaml_lex_token_rec newline lexbuf 0
and __ocaml_lex_token_rec newline lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 171 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( EOF )
# 490 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 1 ->
# 172 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( token newline lexbuf )
# 495 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 2 ->
# 173 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( newline lexbuf; token newline lexbuf )
# 500 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 3 ->
# 174 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( token newline lexbuf )
# 505 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 4 ->
# 177 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( OPEN )
# 510 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 5 ->
# 178 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( CLOSE )
# 515 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 6 ->
let
# 179 "src/languages/smtlib2/v2.6/script/lexer.mll"
               s
# 521 "src/languages/smtlib2/v2.6/script/lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 179 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( NUM s )
# 525 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 7 ->
let
# 180 "src/languages/smtlib2/v2.6/script/lexer.mll"
               s
# 531 "src/languages/smtlib2/v2.6/script/lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 180 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( DEC s )
# 535 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 8 ->
let
# 181 "src/languages/smtlib2/v2.6/script/lexer.mll"
                   s
# 541 "src/languages/smtlib2/v2.6/script/lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 181 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( HEX s )
# 545 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 9 ->
let
# 182 "src/languages/smtlib2/v2.6/script/lexer.mll"
              s
# 551 "src/languages/smtlib2/v2.6/script/lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 182 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( BIN s )
# 555 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 10 ->
# 183 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( string newline (Buffer.create 42) lexbuf )
# 560 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 11 ->
let
# 184 "src/languages/smtlib2/v2.6/script/lexer.mll"
               s
# 566 "src/languages/smtlib2/v2.6/script/lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 184 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( KEYWORD s )
# 570 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 12 ->
let
# 185 "src/languages/smtlib2/v2.6/script/lexer.mll"
                     s
# 576 "src/languages/smtlib2/v2.6/script/lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(1) lexbuf.Lexing.lex_mem.(0) in
# 187 "src/languages/smtlib2/v2.6/script/lexer.mll"
    ( symbol newline lexbuf s )
# 580 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec newline lexbuf __ocaml_lex_state

and string newline b lexbuf =
   __ocaml_lex_string_rec newline b lexbuf 23
and __ocaml_lex_string_rec newline b lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 190 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( Buffer.add_char b '"'; string newline b lexbuf )
# 592 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 1 ->
# 191 "src/languages/smtlib2/v2.6/script/lexer.mll"
                        ( STR (Buffer.contents b) )
# 597 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | 2 ->
let
# 192 "src/languages/smtlib2/v2.6/script/lexer.mll"
                                           c
# 603 "src/languages/smtlib2/v2.6/script/lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 193 "src/languages/smtlib2/v2.6/script/lexer.mll"
    ( if c = '\n' then newline lexbuf;
      Buffer.add_char b c; string newline b lexbuf )
# 608 "src/languages/smtlib2/v2.6/script/lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_string_rec newline b lexbuf __ocaml_lex_state

;;

